0.3 (2012-08-21)
----------------

* Transactions
* Payment gateway integration

0.2 (2012-07-23)
----------------

* Added Talks

0.1 (2012-07-03)
----------------

* First Release
* Models for events, registration, fees and event choices
* Views for listing events and registering
* Signal for e-mailing attendees a verification
* Signal for e-mailing managers when new registrations are added

